// Code generated by MockGen. DO NOT EDIT.
// Source: gitlab.com/gitlab-org/api/client-go/v2 (interfaces: GroupProtectedBranchesServiceInterface)
//
// Generated by this command:
//
//	mockgen -typed -destination=group_protected_branches_mock.go -write_package_comment=false -package=testing gitlab.com/gitlab-org/api/client-go/v2 GroupProtectedBranchesServiceInterface
//

package testing

import (
	reflect "reflect"

	gitlab "gitlab.com/gitlab-org/api/client-go/v2"
	gomock "go.uber.org/mock/gomock"
)

// MockGroupProtectedBranchesServiceInterface is a mock of GroupProtectedBranchesServiceInterface interface.
type MockGroupProtectedBranchesServiceInterface struct {
	ctrl     *gomock.Controller
	recorder *MockGroupProtectedBranchesServiceInterfaceMockRecorder
	isgomock struct{}
}

// MockGroupProtectedBranchesServiceInterfaceMockRecorder is the mock recorder for MockGroupProtectedBranchesServiceInterface.
type MockGroupProtectedBranchesServiceInterfaceMockRecorder struct {
	mock *MockGroupProtectedBranchesServiceInterface
}

// NewMockGroupProtectedBranchesServiceInterface creates a new mock instance.
func NewMockGroupProtectedBranchesServiceInterface(ctrl *gomock.Controller) *MockGroupProtectedBranchesServiceInterface {
	mock := &MockGroupProtectedBranchesServiceInterface{ctrl: ctrl}
	mock.recorder = &MockGroupProtectedBranchesServiceInterfaceMockRecorder{mock}
	return mock
}

// EXPECT returns an object that allows the caller to indicate expected use.
func (m *MockGroupProtectedBranchesServiceInterface) EXPECT() *MockGroupProtectedBranchesServiceInterfaceMockRecorder {
	return m.recorder
}

// GetProtectedBranch mocks base method.
func (m *MockGroupProtectedBranchesServiceInterface) GetProtectedBranch(gid any, branch string, options ...gitlab.RequestOptionFunc) (*gitlab.GroupProtectedBranch, *gitlab.Response, error) {
	m.ctrl.T.Helper()
	varargs := []any{gid, branch}
	for _, a := range options {
		varargs = append(varargs, a)
	}
	ret := m.ctrl.Call(m, "GetProtectedBranch", varargs...)
	ret0, _ := ret[0].(*gitlab.GroupProtectedBranch)
	ret1, _ := ret[1].(*gitlab.Response)
	ret2, _ := ret[2].(error)
	return ret0, ret1, ret2
}

// GetProtectedBranch indicates an expected call of GetProtectedBranch.
func (mr *MockGroupProtectedBranchesServiceInterfaceMockRecorder) GetProtectedBranch(gid, branch any, options ...any) *MockGroupProtectedBranchesServiceInterfaceGetProtectedBranchCall {
	mr.mock.ctrl.T.Helper()
	varargs := append([]any{gid, branch}, options...)
	call := mr.mock.ctrl.RecordCallWithMethodType(mr.mock, "GetProtectedBranch", reflect.TypeOf((*MockGroupProtectedBranchesServiceInterface)(nil).GetProtectedBranch), varargs...)
	return &MockGroupProtectedBranchesServiceInterfaceGetProtectedBranchCall{Call: call}
}

// MockGroupProtectedBranchesServiceInterfaceGetProtectedBranchCall wrap *gomock.Call
type MockGroupProtectedBranchesServiceInterfaceGetProtectedBranchCall struct {
	*gomock.Call
}

// Return rewrite *gomock.Call.Return
func (c *MockGroupProtectedBranchesServiceInterfaceGetProtectedBranchCall) Return(arg0 *gitlab.GroupProtectedBranch, arg1 *gitlab.Response, arg2 error) *MockGroupProtectedBranchesServiceInterfaceGetProtectedBranchCall {
	c.Call = c.Call.Return(arg0, arg1, arg2)
	return c
}

// Do rewrite *gomock.Call.Do
func (c *MockGroupProtectedBranchesServiceInterfaceGetProtectedBranchCall) Do(f func(any, string, ...gitlab.RequestOptionFunc) (*gitlab.GroupProtectedBranch, *gitlab.Response, error)) *MockGroupProtectedBranchesServiceInterfaceGetProtectedBranchCall {
	c.Call = c.Call.Do(f)
	return c
}

// DoAndReturn rewrite *gomock.Call.DoAndReturn
func (c *MockGroupProtectedBranchesServiceInterfaceGetProtectedBranchCall) DoAndReturn(f func(any, string, ...gitlab.RequestOptionFunc) (*gitlab.GroupProtectedBranch, *gitlab.Response, error)) *MockGroupProtectedBranchesServiceInterfaceGetProtectedBranchCall {
	c.Call = c.Call.DoAndReturn(f)
	return c
}

// ListProtectedBranches mocks base method.
func (m *MockGroupProtectedBranchesServiceInterface) ListProtectedBranches(gid any, opt *gitlab.ListGroupProtectedBranchesOptions, options ...gitlab.RequestOptionFunc) ([]*gitlab.GroupProtectedBranch, *gitlab.Response, error) {
	m.ctrl.T.Helper()
	varargs := []any{gid, opt}
	for _, a := range options {
		varargs = append(varargs, a)
	}
	ret := m.ctrl.Call(m, "ListProtectedBranches", varargs...)
	ret0, _ := ret[0].([]*gitlab.GroupProtectedBranch)
	ret1, _ := ret[1].(*gitlab.Response)
	ret2, _ := ret[2].(error)
	return ret0, ret1, ret2
}

// ListProtectedBranches indicates an expected call of ListProtectedBranches.
func (mr *MockGroupProtectedBranchesServiceInterfaceMockRecorder) ListProtectedBranches(gid, opt any, options ...any) *MockGroupProtectedBranchesServiceInterfaceListProtectedBranchesCall {
	mr.mock.ctrl.T.Helper()
	varargs := append([]any{gid, opt}, options...)
	call := mr.mock.ctrl.RecordCallWithMethodType(mr.mock, "ListProtectedBranches", reflect.TypeOf((*MockGroupProtectedBranchesServiceInterface)(nil).ListProtectedBranches), varargs...)
	return &MockGroupProtectedBranchesServiceInterfaceListProtectedBranchesCall{Call: call}
}

// MockGroupProtectedBranchesServiceInterfaceListProtectedBranchesCall wrap *gomock.Call
type MockGroupProtectedBranchesServiceInterfaceListProtectedBranchesCall struct {
	*gomock.Call
}

// Return rewrite *gomock.Call.Return
func (c *MockGroupProtectedBranchesServiceInterfaceListProtectedBranchesCall) Return(arg0 []*gitlab.GroupProtectedBranch, arg1 *gitlab.Response, arg2 error) *MockGroupProtectedBranchesServiceInterfaceListProtectedBranchesCall {
	c.Call = c.Call.Return(arg0, arg1, arg2)
	return c
}

// Do rewrite *gomock.Call.Do
func (c *MockGroupProtectedBranchesServiceInterfaceListProtectedBranchesCall) Do(f func(any, *gitlab.ListGroupProtectedBranchesOptions, ...gitlab.RequestOptionFunc) ([]*gitlab.GroupProtectedBranch, *gitlab.Response, error)) *MockGroupProtectedBranchesServiceInterfaceListProtectedBranchesCall {
	c.Call = c.Call.Do(f)
	return c
}

// DoAndReturn rewrite *gomock.Call.DoAndReturn
func (c *MockGroupProtectedBranchesServiceInterfaceListProtectedBranchesCall) DoAndReturn(f func(any, *gitlab.ListGroupProtectedBranchesOptions, ...gitlab.RequestOptionFunc) ([]*gitlab.GroupProtectedBranch, *gitlab.Response, error)) *MockGroupProtectedBranchesServiceInterfaceListProtectedBranchesCall {
	c.Call = c.Call.DoAndReturn(f)
	return c
}

// ProtectRepositoryBranches mocks base method.
func (m *MockGroupProtectedBranchesServiceInterface) ProtectRepositoryBranches(gid any, opt *gitlab.ProtectGroupRepositoryBranchesOptions, options ...gitlab.RequestOptionFunc) (*gitlab.GroupProtectedBranch, *gitlab.Response, error) {
	m.ctrl.T.Helper()
	varargs := []any{gid, opt}
	for _, a := range options {
		varargs = append(varargs, a)
	}
	ret := m.ctrl.Call(m, "ProtectRepositoryBranches", varargs...)
	ret0, _ := ret[0].(*gitlab.GroupProtectedBranch)
	ret1, _ := ret[1].(*gitlab.Response)
	ret2, _ := ret[2].(error)
	return ret0, ret1, ret2
}

// ProtectRepositoryBranches indicates an expected call of ProtectRepositoryBranches.
func (mr *MockGroupProtectedBranchesServiceInterfaceMockRecorder) ProtectRepositoryBranches(gid, opt any, options ...any) *MockGroupProtectedBranchesServiceInterfaceProtectRepositoryBranchesCall {
	mr.mock.ctrl.T.Helper()
	varargs := append([]any{gid, opt}, options...)
	call := mr.mock.ctrl.RecordCallWithMethodType(mr.mock, "ProtectRepositoryBranches", reflect.TypeOf((*MockGroupProtectedBranchesServiceInterface)(nil).ProtectRepositoryBranches), varargs...)
	return &MockGroupProtectedBranchesServiceInterfaceProtectRepositoryBranchesCall{Call: call}
}

// MockGroupProtectedBranchesServiceInterfaceProtectRepositoryBranchesCall wrap *gomock.Call
type MockGroupProtectedBranchesServiceInterfaceProtectRepositoryBranchesCall struct {
	*gomock.Call
}

// Return rewrite *gomock.Call.Return
func (c *MockGroupProtectedBranchesServiceInterfaceProtectRepositoryBranchesCall) Return(arg0 *gitlab.GroupProtectedBranch, arg1 *gitlab.Response, arg2 error) *MockGroupProtectedBranchesServiceInterfaceProtectRepositoryBranchesCall {
	c.Call = c.Call.Return(arg0, arg1, arg2)
	return c
}

// Do rewrite *gomock.Call.Do
func (c *MockGroupProtectedBranchesServiceInterfaceProtectRepositoryBranchesCall) Do(f func(any, *gitlab.ProtectGroupRepositoryBranchesOptions, ...gitlab.RequestOptionFunc) (*gitlab.GroupProtectedBranch, *gitlab.Response, error)) *MockGroupProtectedBranchesServiceInterfaceProtectRepositoryBranchesCall {
	c.Call = c.Call.Do(f)
	return c
}

// DoAndReturn rewrite *gomock.Call.DoAndReturn
func (c *MockGroupProtectedBranchesServiceInterfaceProtectRepositoryBranchesCall) DoAndReturn(f func(any, *gitlab.ProtectGroupRepositoryBranchesOptions, ...gitlab.RequestOptionFunc) (*gitlab.GroupProtectedBranch, *gitlab.Response, error)) *MockGroupProtectedBranchesServiceInterfaceProtectRepositoryBranchesCall {
	c.Call = c.Call.DoAndReturn(f)
	return c
}

// UnprotectRepositoryBranches mocks base method.
func (m *MockGroupProtectedBranchesServiceInterface) UnprotectRepositoryBranches(gid any, branch string, options ...gitlab.RequestOptionFunc) (*gitlab.Response, error) {
	m.ctrl.T.Helper()
	varargs := []any{gid, branch}
	for _, a := range options {
		varargs = append(varargs, a)
	}
	ret := m.ctrl.Call(m, "UnprotectRepositoryBranches", varargs...)
	ret0, _ := ret[0].(*gitlab.Response)
	ret1, _ := ret[1].(error)
	return ret0, ret1
}

// UnprotectRepositoryBranches indicates an expected call of UnprotectRepositoryBranches.
func (mr *MockGroupProtectedBranchesServiceInterfaceMockRecorder) UnprotectRepositoryBranches(gid, branch any, options ...any) *MockGroupProtectedBranchesServiceInterfaceUnprotectRepositoryBranchesCall {
	mr.mock.ctrl.T.Helper()
	varargs := append([]any{gid, branch}, options...)
	call := mr.mock.ctrl.RecordCallWithMethodType(mr.mock, "UnprotectRepositoryBranches", reflect.TypeOf((*MockGroupProtectedBranchesServiceInterface)(nil).UnprotectRepositoryBranches), varargs...)
	return &MockGroupProtectedBranchesServiceInterfaceUnprotectRepositoryBranchesCall{Call: call}
}

// MockGroupProtectedBranchesServiceInterfaceUnprotectRepositoryBranchesCall wrap *gomock.Call
type MockGroupProtectedBranchesServiceInterfaceUnprotectRepositoryBranchesCall struct {
	*gomock.Call
}

// Return rewrite *gomock.Call.Return
func (c *MockGroupProtectedBranchesServiceInterfaceUnprotectRepositoryBranchesCall) Return(arg0 *gitlab.Response, arg1 error) *MockGroupProtectedBranchesServiceInterfaceUnprotectRepositoryBranchesCall {
	c.Call = c.Call.Return(arg0, arg1)
	return c
}

// Do rewrite *gomock.Call.Do
func (c *MockGroupProtectedBranchesServiceInterfaceUnprotectRepositoryBranchesCall) Do(f func(any, string, ...gitlab.RequestOptionFunc) (*gitlab.Response, error)) *MockGroupProtectedBranchesServiceInterfaceUnprotectRepositoryBranchesCall {
	c.Call = c.Call.Do(f)
	return c
}

// DoAndReturn rewrite *gomock.Call.DoAndReturn
func (c *MockGroupProtectedBranchesServiceInterfaceUnprotectRepositoryBranchesCall) DoAndReturn(f func(any, string, ...gitlab.RequestOptionFunc) (*gitlab.Response, error)) *MockGroupProtectedBranchesServiceInterfaceUnprotectRepositoryBranchesCall {
	c.Call = c.Call.DoAndReturn(f)
	return c
}

// UpdateProtectedBranch mocks base method.
func (m *MockGroupProtectedBranchesServiceInterface) UpdateProtectedBranch(gid any, branch string, opt *gitlab.UpdateGroupProtectedBranchOptions, options ...gitlab.RequestOptionFunc) (*gitlab.GroupProtectedBranch, *gitlab.Response, error) {
	m.ctrl.T.Helper()
	varargs := []any{gid, branch, opt}
	for _, a := range options {
		varargs = append(varargs, a)
	}
	ret := m.ctrl.Call(m, "UpdateProtectedBranch", varargs...)
	ret0, _ := ret[0].(*gitlab.GroupProtectedBranch)
	ret1, _ := ret[1].(*gitlab.Response)
	ret2, _ := ret[2].(error)
	return ret0, ret1, ret2
}

// UpdateProtectedBranch indicates an expected call of UpdateProtectedBranch.
func (mr *MockGroupProtectedBranchesServiceInterfaceMockRecorder) UpdateProtectedBranch(gid, branch, opt any, options ...any) *MockGroupProtectedBranchesServiceInterfaceUpdateProtectedBranchCall {
	mr.mock.ctrl.T.Helper()
	varargs := append([]any{gid, branch, opt}, options...)
	call := mr.mock.ctrl.RecordCallWithMethodType(mr.mock, "UpdateProtectedBranch", reflect.TypeOf((*MockGroupProtectedBranchesServiceInterface)(nil).UpdateProtectedBranch), varargs...)
	return &MockGroupProtectedBranchesServiceInterfaceUpdateProtectedBranchCall{Call: call}
}

// MockGroupProtectedBranchesServiceInterfaceUpdateProtectedBranchCall wrap *gomock.Call
type MockGroupProtectedBranchesServiceInterfaceUpdateProtectedBranchCall struct {
	*gomock.Call
}

// Return rewrite *gomock.Call.Return
func (c *MockGroupProtectedBranchesServiceInterfaceUpdateProtectedBranchCall) Return(arg0 *gitlab.GroupProtectedBranch, arg1 *gitlab.Response, arg2 error) *MockGroupProtectedBranchesServiceInterfaceUpdateProtectedBranchCall {
	c.Call = c.Call.Return(arg0, arg1, arg2)
	return c
}

// Do rewrite *gomock.Call.Do
func (c *MockGroupProtectedBranchesServiceInterfaceUpdateProtectedBranchCall) Do(f func(any, string, *gitlab.UpdateGroupProtectedBranchOptions, ...gitlab.RequestOptionFunc) (*gitlab.GroupProtectedBranch, *gitlab.Response, error)) *MockGroupProtectedBranchesServiceInterfaceUpdateProtectedBranchCall {
	c.Call = c.Call.Do(f)
	return c
}

// DoAndReturn rewrite *gomock.Call.DoAndReturn
func (c *MockGroupProtectedBranchesServiceInterfaceUpdateProtectedBranchCall) DoAndReturn(f func(any, string, *gitlab.UpdateGroupProtectedBranchOptions, ...gitlab.RequestOptionFunc) (*gitlab.GroupProtectedBranch, *gitlab.Response, error)) *MockGroupProtectedBranchesServiceInterfaceUpdateProtectedBranchCall {
	c.Call = c.Call.DoAndReturn(f)
	return c
}
